export default function colorSchemeHandler(container, theme) {
    let allowedThemes = ["white", "black", "match", "contrast"];
    if (allowedThemes.includes(theme) == false) throw new Error(`HyperModals: ${theme} is an unknown theme`);

    // Simple white/black themes
    if (["white", "black"].includes(theme)) {
        container.classList.add(`hm-th${theme}`);
    }

    // Match/Contrast based theme
    if (["match", "contrast"].includes(theme)) {
        // Method for applying a match/contrast based theme
        let applyTheme = (colorScheme) => {
            if (theme == "match") {
                if (colorScheme == "light") container.classList.add(`hm-thwhite`);
                if (colorScheme == "dark") container.classList.add(`hm-thblack`);
            } else {
                if (colorScheme == "light") container.classList.add(`hm-thblack`);
                if (colorScheme == "dark") container.classList.add(`hm-thwhite`);
            }
        };

        // Apply current (at time of init) theme
        let currentColorScheme = window.matchMedia && window.matchMedia("(prefers-color-scheme: dark)").matches ? "dark" : "light";
        applyTheme(currentColorScheme);

        // Update after user changes color scheme
        window.matchMedia("(prefers-color-scheme: dark)").addEventListener("change", (event) => {
            // Clear any previous themes from element
            allowedThemes.forEach((theme) => {
                container.classList.remove(`hm-th${theme}`);
            });

            let newColorScheme = event.matches ? "dark" : "light";
            applyTheme(newColorScheme);
        });
    }
}
