import _ from "lodash";

// Method for mapping provided config keys over a default config
export default function mergeConfig(defaultConfig, providedConfig) {
    // If providedConfig is null, then just return defaultConfig
    if (_.isObject(providedConfig) == false) {
        return defaultConfig;
    }

    return _.mapValues(defaultConfig, (value, key) => {
        // If key in providedConfig is preent, mix values recursively
        if (_.has(providedConfig, key)) {
            // If value is an object => Call function recursively
            if (_.isObject(value)) {
                return mergeConfig(value, providedConfig[key]);
            } else {
                // Else: Just copy value over
                return providedConfig[key];
            }
        } else {
            // Else: Keep default value
            return value;
        }
    });
}
